"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseDatabricksJdbcUrl = exports.extractAndRemoveUidPwdFromJdbcUrl = exports.resolveJDBCDriver = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const installer_1 = require("./installer");
async function fileExistsOr(fsPath, fn) {
    if (fs_1.default.existsSync(fsPath)) {
        return fsPath;
    }
    return fn();
}
async function resolveJDBCDriver() {
    return fileExistsOr(path_1.default.join(process.cwd(), `databricks-jdbc-${installer_1.OSS_DRIVER_VERSION}-oss.jar`), async () => fileExistsOr(path_1.default.join(__dirname, '..', 'download', `databricks-jdbc-${installer_1.OSS_DRIVER_VERSION}-oss.jar`), async () => {
        const pathOrNull = await (0, installer_1.downloadJDBCDriver)();
        if (pathOrNull) {
            return pathOrNull;
        }
        throw new Error(`Please download and place databricks-jdbc-${installer_1.OSS_DRIVER_VERSION}-oss.jar inside your ` +
            'project directory');
    }));
}
exports.resolveJDBCDriver = resolveJDBCDriver;
/**
 * Extract if exist UID and PWD from URL and return UID, PWD and URL without these params.
 * New Databricks OSS driver throws an error if UID and PWD are provided in the URL and as a separate params
 * passed to the driver instance. That's why we strip them out from the URL if they exist there.
 * @param jdbcUrl
 */
function extractAndRemoveUidPwdFromJdbcUrl(jdbcUrl) {
    const uidMatch = jdbcUrl.match(/UID=([^;]*)/i);
    const pwdMatch = jdbcUrl.match(/PWD=([^;]*)/i);
    const uid = uidMatch?.[1] || 'token';
    const pwd = pwdMatch?.[1] || '';
    const cleanedUrl = jdbcUrl
        .replace(/;?UID=[^;]*/i, '')
        .replace(/;?PWD=[^;]*/i, '');
    return [uid, pwd, cleanedUrl];
}
exports.extractAndRemoveUidPwdFromJdbcUrl = extractAndRemoveUidPwdFromJdbcUrl;
function parseDatabricksJdbcUrl(jdbcUrl) {
    const jdbcPrefix = 'jdbc:databricks://';
    const urlWithoutPrefix = jdbcUrl.slice(jdbcPrefix.length);
    const [hostPortAndPath, ...params] = urlWithoutPrefix.split(';');
    const [host] = hostPortAndPath.split(':');
    const paramMap = new Map();
    for (const param of params) {
        const [key, value] = param.split('=');
        if (key && value) {
            paramMap.set(key, value);
        }
    }
    const httpPath = paramMap.get('httpPath');
    if (!httpPath) {
        throw new Error('Missing httpPath in JDBC URL');
    }
    const warehouseMatch = httpPath.match(/\/warehouses\/([a-zA-Z0-9]+)/);
    if (!warehouseMatch) {
        throw new Error('Could not extract warehouseId from httpPath');
    }
    const warehouseId = warehouseMatch[1];
    return { host, warehouseId };
}
exports.parseDatabricksJdbcUrl = parseDatabricksJdbcUrl;
//# sourceMappingURL=helpers.js.map